@@ -73,13 +73,13 @@ class Formatter:
                 i = self.__skip_ws_tokens(i + 1)
                 if self.__tokens[i].get_token_type() == TokenType.IDENTIFIER:
                     if Formatter.__is_not_upper_camel_case(self.__tokens[i].get_value()):
-                        self.__tokens[i].set_fixed_value(
-                            Formatter.snake_to_upper_camel_case(self.__tokens[i].get_value()))
+                        self.__fix_similar(self.__tokens[i].get_primary_value(),
+                                           Formatter.snake_to_upper_camel_case(self.__tokens[i].get_value()))
                     i += 1
             # lower case camel case for annotation
             elif token.get_token_type() == TokenType.ANNOTATION and Formatter.__is_not_lower_camel_case(
-                    token.get_value()):
-                token.set_fixed_value(Formatter.snake_to_lower_camel_case(token.get_value()))
+                    token.get_value()[1:]):
+                token.set_fixed_value('@' + Formatter.snake_to_lower_camel_case(token.get_value()[1:]))
                 i += 1
             # package as in Java naming convention
             elif token.get_value() == 'package':
@@ -92,9 +92,24 @@ class Formatter:
                     i = self.__fix_packages(i) - 1
                     continue
                 i = self.__fix_class_trait_object(i) - 1
-            elif token.get_token_type() == TokenType.IDENTIFIER and token.get_fixed_value() is None and \
-                    Formatter.__is_not_lower_camel_case(token.get_value()):
-                token.set_fixed_value(Formatter.snake_to_lower_camel_case(token.get_value()))
+            elif token.get_value() == 'def':
+                i += 1
+                while self.__tokens[i].get_token_type() != TokenType.IDENTIFIER:
+                    i += 1
+                if Formatter.__is_not_lower_camel_case(self.__tokens[i].get_value()):
+                    self.__fix_similar(self.__tokens[i].get_primary_value(),
+                                       Formatter.snake_to_lower_camel_case(self.__tokens[i].get_value()))
+                i += 1
+            elif token.get_token_type() == TokenType.IDENTIFIER and token.get_fixed_value() is None:
+                pos = i + 1
+                while self.__tokens[pos].get_value() == ' ':
+                    pos += 1
+                if self.__tokens[pos].get_value() not in (
+                        '.', '[', 'extends', '(', '{') and Formatter.__is_not_lower_camel_case(
+                    token.get_value()):
+
+                    self.__fix_similar(token.get_primary_value(),
+                                       Formatter.snake_to_lower_camel_case(token.get_value()))
                 i += 1
             else:
                 i += 1
@@ -108,7 +123,7 @@ class Formatter:
                 brace_count -= 1
             elif brace_count > 0 and token.get_token_type() == TokenType.IDENTIFIER and Formatter.__is_not_upper_camel_case(
                     token.get_value()):
-                token.set_fixed_value(Formatter.snake_to_upper_camel_case(token.get_value()))
+                self.__fix_similar(token.get_primary_value(), Formatter.snake_to_upper_camel_case(token.get_value()))
 
     def __fix_packages(self, pos):
         pos = self.__skip_ws_tokens(pos + 1)
@@ -125,7 +140,7 @@ class Formatter:
         if self.__tokens[pos].get_token_type() == TokenType.IDENTIFIER and Formatter.__is_not_upper_camel_case(
                 self.__tokens[pos].get_value()):
             fixed_value = Formatter.snake_to_upper_camel_case(self.__tokens[pos].get_value())
-            self.__tokens[pos].set_fixed_value(fixed_value)
+            self.__fix_similar(self.__tokens[pos].get_primary_value(), fixed_value)
             pos += 1
         return pos
 
@@ -676,3 +691,11 @@ class Formatter:
             while comment[i] not in ('\n', '*'):
                 i += 1
             return i
+
+    def __fix_similar(self, token_before, token_after):
+        i = 0
+        while i < len(self.__tokens):
+            token = self.__tokens[i]
+            if token.get_primary_value() == token_before:
+                token.set_fixed_value(token_after)
+            i += 1
